@@ -16,8 +16,9 @@
 
 #if HAVE_CANBERRA
 #include <canberra.h>
-#elif HAVE_PHONON
-#include <phonon/mediaobject.h>
+#elif HAVE_QTMULTIMEDIA
+#include <QAudioOutput>
+#include <QMediaPlayer>
 #endif
 
 KNotifyConfigActionsWidget::KNotifyConfigActionsWidget(QWidget *parent)
@@ -35,29 +36,11 @@ KNotifyConfigActionsWidget::KNotifyConfigActionsWidget(QWidget *parent)
     m_ui.Sound_play->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
     m_ui.Sound_check->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
     m_ui.Popup_check->setIcon(QIcon::fromTheme(QStringLiteral("dialog-information")));
-    m_ui.Logfile_check->setIcon(QIcon::fromTheme(QStringLiteral("text-x-generic")));
-    m_ui.Execute_check->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
-    m_ui.Taskbar_check->setIcon(QIcon::fromTheme(QStringLiteral("services")));
-    m_ui.TTS_check->setIcon(QIcon::fromTheme(QStringLiteral("text-speak")));
 
-    connect(m_ui.Execute_check, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
     connect(m_ui.Sound_check, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
     connect(m_ui.Popup_check, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
-    connect(m_ui.Logfile_check, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
-    connect(m_ui.Taskbar_check, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
-    connect(m_ui.TTS_check, SIGNAL(toggled(bool)), this, SLOT(slotTTSComboChanged()));
-    connect(m_ui.Execute_select, SIGNAL(textChanged(QString)), this, SIGNAL(changed()));
     connect(m_ui.Sound_select, SIGNAL(textChanged(QString)), this, SIGNAL(changed()));
-    connect(m_ui.Logfile_select, SIGNAL(textChanged(QString)), this, SIGNAL(changed()));
     connect(m_ui.Sound_play, SIGNAL(clicked()), this, SLOT(slotPlay()));
-    connect(m_ui.TTS_select, SIGNAL(textChanged(QString)), this, SIGNAL(changed()));
-    connect(m_ui.TTS_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(slotTTSComboChanged()));
-    m_ui.TTS_combo->setEnabled(false);
-    if (!KNotifyConfigElement::have_tts()) {
-        m_ui.TTS_check->setVisible(false);
-        m_ui.TTS_select->setVisible(false);
-        m_ui.TTS_combo->setVisible(false);
-    }
 }
 
 KNotifyConfigActionsWidget::~KNotifyConfigActionsWidget()
@@ -78,22 +61,9 @@ void KNotifyConfigActionsWidget::setConfigElement(KNotifyConfigElement *config)
 
     m_ui.Sound_check->setChecked(actions.contains(QStringLiteral("Sound")));
     m_ui.Popup_check->setChecked(actions.contains(QStringLiteral("Popup")));
-    m_ui.Logfile_check->setChecked(actions.contains(QStringLiteral("Logfile")));
-    m_ui.Execute_check->setChecked(actions.contains(QStringLiteral("Execute")));
-    m_ui.Taskbar_check->setChecked(actions.contains(QStringLiteral("Taskbar")));
-    m_ui.TTS_check->setChecked(actions.contains(QStringLiteral("TTS")));
 
     m_ui.Sound_select->setUrl(QUrl(config->readEntry(QStringLiteral("Sound"), true)));
-    m_ui.Logfile_select->setUrl(QUrl(config->readEntry(QStringLiteral("Logfile"), true)));
-    m_ui.Execute_select->setUrl(QUrl::fromLocalFile(config->readEntry(QStringLiteral("Execute"))));
-    m_ui.TTS_select->setText(config->readEntry(QStringLiteral("TTS")));
-    if (m_ui.TTS_select->text() == QLatin1String("%e")) {
-        m_ui.TTS_combo->setCurrentIndex(1);
-    } else if (m_ui.TTS_select->text() == QLatin1String("%m") || m_ui.TTS_select->text() == QLatin1String("%s")) {
-        m_ui.TTS_combo->setCurrentIndex(0);
-    } else {
-        m_ui.TTS_combo->setCurrentIndex(2);
-    }
+
     blockSignals(blocked);
 }
 
@@ -106,36 +76,11 @@ void KNotifyConfigActionsWidget::save(KNotifyConfigElement *config)
     if (m_ui.Popup_check->isChecked()) {
         actions << QStringLiteral("Popup");
     }
-    if (m_ui.Logfile_check->isChecked()) {
-        actions << QStringLiteral("Logfile");
-    }
-    if (m_ui.Execute_check->isChecked()) {
-        actions << QStringLiteral("Execute");
-    }
-    if (m_ui.Taskbar_check->isChecked()) {
-        actions << QStringLiteral("Taskbar");
-    }
-    if (m_ui.TTS_check->isChecked()) {
-        actions << QStringLiteral("TTS");
-    }
 
     config->writeEntry(QStringLiteral("Action"), actions.join(QLatin1Char('|')));
 
     config->writeEntry(QStringLiteral("Sound"),
                        m_ui.Sound_select->text()); // don't use .url() here, .notifyrc files have predefined "static" entries with no path
-    config->writeEntry(QStringLiteral("Logfile"), m_ui.Logfile_select->url().toString());
-    config->writeEntry(QStringLiteral("Execute"), m_ui.Execute_select->url().toLocalFile());
-    switch (m_ui.TTS_combo->currentIndex()) {
-    case 0:
-        config->writeEntry(QStringLiteral("TTS"), QStringLiteral("%s"));
-        break;
-    case 1:
-        config->writeEntry(QStringLiteral("TTS"), QStringLiteral("%e"));
-        break;
-    case 2:
-    default:
-        config->writeEntry(QStringLiteral("TTS"), m_ui.TTS_select->text());
-    }
 }
 
 void KNotifyConfigActionsWidget::slotPlay()
@@ -197,17 +142,21 @@ void KNotifyConfigActionsWidget::slotPlay()
         qCWarning(KNOTIFYCONFIG_LOG) << "Failed to play sound with canberra:" << ca_strerror(ret);
         return;
     }
-#elif HAVE_PHONON
-    Phonon::MediaObject *media = Phonon::createPlayer(Phonon::NotificationCategory, soundURL);
-    media->play();
-    connect(media, SIGNAL(finished()), media, SLOT(deleteLater()));
+#elif HAVE_QTMULTIMEDIA
+    auto player = new QMediaPlayer(this);
+    auto audioOutput = new QAudioOutput(player);
+    connect(player, &QMediaPlayer::playingChanged, player, [player](bool playing) {
+        if (!playing) {
+            player->deleteLater();
+        }
+    });
+    connect(player, &QMediaPlayer::errorOccurred, player, [player]() {
+        player->deleteLater();
+    });
+    player->setAudioOutput(audioOutput);
+    player->setSource(soundURL);
+    player->play();
 #endif
 }
 
-void KNotifyConfigActionsWidget::slotTTSComboChanged()
-{
-    m_ui.TTS_select->setEnabled(m_ui.TTS_check->isChecked() && m_ui.TTS_combo->currentIndex() == 2);
-    Q_EMIT changed();
-}
-
 #include "moc_knotifyconfigactionswidget.cpp"
